OnReceiveStartCallAction typedef
Device sends this event once it decides the app is allowed to start a call, either from the built-in phone screens (iOS/Recents), or by the app calling RNCallKeep.startCall.
Try to start your app call action from here (e.g. get credentials of the user by data.handle and/or send INVITE to your SIP server)
Note: on iOS callUUID is not defined as the call is not yet managed by CallKit. You have to generate your own and call startCall.
uuid - The UUID of the call that is to be answered
handle - Phone number of the callee see HandleType for other options
Implementation
typedef Future<dynamic> OnReceiveStartCallAction(String uuid, String handle);